<?php
/**
 * slider section
 *
 * @package Jumla
 */

$default = jumla_get_default_theme_options();

// Slider Main Section.
$wp_customize->add_section('slider_section_settings',
	array(
		'title'      => esc_html__('Slider Section Options', 'jumla'),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'theme_option_panel',
	)
);

// Setting - show_slider_section.
$wp_customize->add_setting('show_slider_section',
	array(
		'default'           => $default['show_slider_section'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'jumla_sanitize_checkbox',
	)
);
$wp_customize->add_control('show_slider_section',
	array(
		'label'    => esc_html__('Enable Slider', 'jumla'),
		'section'  => 'slider_section_settings',
		'type'     => 'checkbox',
		'priority' => 100,
	)
);

/*No of Slider*/
$wp_customize->add_setting('number_of_home_slider',
	array(
		'default'           => $default['number_of_home_slider'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'jumla_sanitize_positive_integer',
	)
);
$wp_customize->add_control('number_of_home_slider',
	array(
		'label'       => esc_html__('Select no of slider', 'jumla'),
		'description' => esc_html__('Number of slider you wish to display on your front page (1-4)', 'jumla'),
		'section'     => 'slider_section_settings',
		'type'     => 'number',
		'input_attrs' => array('min' => 0, 'max' => 4, 'style' => 'width: 150px;'),
		'priority' => 105,
	)
);

/*content excerpt in Slider*/
$wp_customize->add_setting('number_of_content_home_slider',
	array(
		'default'           => $default['number_of_content_home_slider'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'jumla_sanitize_positive_integer',
	)
);
$wp_customize->add_control('number_of_content_home_slider',
	array(
		'label'       => esc_html__('Select no words of slider', 'jumla'),
		'section'     => 'slider_section_settings',
		'type'        => 'number',
		'priority'    => 110,
		'input_attrs' => array('min' => 0, 'max' => 200, 'style' => 'width: 150px;'),

	)
);


// Setting - drop down category for slider.
$wp_customize->add_setting('select_category_for_slider',
	array(
		'default'           => $default['select_category_for_slider'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(new Jumla_Dropdown_Taxonomies_Control($wp_customize, 'select_category_for_slider',
		array(
			'label'           => esc_html__('Category for slider', 'jumla'),
			'description'     => esc_html__('Select category to be shown on tab ', 'jumla'),
			'section'         => 'slider_section_settings',
			'type'            => 'dropdown-taxonomies',
			'taxonomy'        => 'category',
			'priority'        => 130,

		)));

/*settings for Section property*/
/*Button Text*/
$wp_customize->add_setting('button_text_on_slider',
	array(
		'default'           => $default['button_text_on_slider'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control('button_text_on_slider',
	array(
		'label'       => esc_html__('Read More Text', 'jumla'),
		'description' => esc_html__('Removing text will disable read more on the slider', 'jumla'),
		'section'     => 'slider_section_settings',
		'type'        => 'text',
		'priority'    => 170,
	)
);

$wp_customize->add_setting('show_cat_post_list',
	array(
		'default'           => $default['show_cat_post_list'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'jumla_sanitize_checkbox',
	)
);
$wp_customize->add_control('show_cat_post_list',
	array(
		'label'    => esc_html__('Enable Category Post List', 'jumla'),
		'section'  => 'slider_section_settings',
		'type'     => 'checkbox',
		'priority' => 170,
	)
);

$wp_customize->add_setting('select_category_for_list',
	array(
		'default'           => $default['select_category_for_list'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(new Jumla_Dropdown_Taxonomies_Control($wp_customize, 'select_category_for_list',
		array(
			'label'           => esc_html__('Category Post List', 'jumla'),
			'description'     => esc_html__('Select category to be shown on the Side of Slider ', 'jumla'),
			'section'         => 'slider_section_settings',
			'type'            => 'dropdown-taxonomies',
			'taxonomy'        => 'category',
			'priority'        => 170,
			'active_callback' => 'jumla_is_category_post_list',
		)));

// Intro Section.
$wp_customize->add_section('intro_section_settings',
    array(
        'title' => esc_html__('Intro Section Options', 'jumla'),
        'priority' => 100,
        'capability' => 'edit_theme_options',
        'panel' => 'theme_option_panel',
    )
);
// Setting - show_intro_section_section.
$wp_customize->add_setting('show_intro_section_section',
    array(
        'default' => $default['show_intro_section_section'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'jumla_sanitize_checkbox',
    )
);
$wp_customize->add_control('show_intro_section_section',
    array(
        'label' => esc_html__('Enable Intro Section', 'jumla'),
        'section' => 'intro_section_settings',
        'type' => 'checkbox',
        'priority' => 100,
    )
);


//intro section image and url
for ( $i=1; $i <= 3 ; $i++ ) {
        $wp_customize->add_setting( 'title_for_intro_'.$i, array(
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_text_field',
        ) );

        $wp_customize->add_control( 'title_for_intro_'.$i, array(
            'label'             => esc_html__( 'Title For Intor Section ', 'jumla' ) . ' - ' . $i ,
            'priority'          =>  '120' . $i,
            'section'           => 'intro_section_settings',
            'type'              => 'text',
            'priority'          => 120,
            )
        );
        $wp_customize->add_setting( 'intro_section_image_'.$i, array(
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'jumla_sanitize_image',
        ) );
        $wp_customize->add_control(
            new WP_Customize_Image_Control( $wp_customize, 'intro_section_image_'.$i,
            array(
            'label'             => esc_html__( 'Upload Image For Intro Section ', 'jumla' ) . ' - ' . $i ,
            'section'         => 'intro_section_settings',
            'priority'        => 120,
            )
        )
        );
        $wp_customize->add_setting( 'url_for_intro_'.$i, array(
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_url_raw',
        ) );

        $wp_customize->add_control( 'url_for_intro_'.$i, array(
            'label'             => esc_html__( 'URL For Intor Section ', 'jumla' ) . ' - ' . $i ,
            'priority'          =>  '120' . $i,
            'section'           => 'intro_section_settings',
            'type'              => 'text',
            'priority'          => 120,
            )
        );
    }